eprllib.Env.MultiAgent — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Env.MultiAgent

## Multi-Agent Environment

The multi-agent aproach allow to run multiples agents in the environment, but also a single agent.

The standard configuration use a policy with fully shared parameters.

You can configure the environment with the `EnvConfig` class .

Modules

`EnergyPlusEnvironment` | Multi-Agent Environment for EnergyPlus in RLlib
`EnergyPlusRunner` | EnergyPlus Runner
`EnvUtils` | Environment Utilities